NbpClient class
Simple client for the NBP (Narodowy Bank Polski) Web API (https://api.nbp.pl). Implements the exchange-rate lookup rules for KSeF invoices.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rateForTaxObligationDate(
{required String currency, required DateTime taxObligationDate}) → Future< NbpRate> -
Returns the NBP average rate for
currencyfor given tax obligation date. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited