NbpRate class
A single exchange rate entry returned by the NBP API.
Constructors
Properties
- code → String
-
The ISO 4217 currency code.
final
- currency → String
-
The currency code (e.g. "EUR", "USD").
final
- effectiveDate → DateTime
-
The date for which this rate is effective.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mid → double
-
The average (mid) exchange rate against PLN.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableNo → String
-
The NBP table number (e.g. "121/A/NBP/2025").
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited